#ifndef __JSON_GLIB_H__
#define __JSON_GLIB_H__

#define __JSON_GLIB_INSIDE__

#include "json-types.h"
#include "json-generator.h"
#include "json-parser.h"

#undef __JSON_GLIB_INSIDE__

#endif /* __JSON_GLIB_H__ */
